@@ -1,30 +1,30 @@
 extern crate clap;
 
-use clap::{App, Arg};
+use clap::{Arg, Command};
 use jaslog::read_log;
 
 fn main() {
-  const VERSION: &'static str = env!("CARGO_PKG_VERSION");
+  const VERSION: &str = env!("CARGO_PKG_VERSION");
 
-  let options = App::new("jaslog")
+  let options = Command::new("jaslog")
     .version(VERSION)
     .about("JSON logs reader for JSON logs")
 
-    .arg(Arg::with_name("filters")
-      .short("f")
+    .arg(Arg::new("filters")
+      .short('f')
       .long("filter")
       .help("Filter the logs. Example:  -f app=this -f module=+Drive (use '+' to search within the field, use '^' to exclude within the field)")
       .takes_value(true)
       .number_of_values(1)
-      .multiple(true))
+      .multiple_occurrences(true))
 
-    .arg(Arg::with_name("number_of_lines")
-      .short("n")
+    .arg(Arg::new("number_of_lines")
+      .short('n')
       .long("lines")
       .help("Number of lines to read.")
       .takes_value(true))
 
-    .arg(Arg::with_name("input_file")
+    .arg(Arg::new("input_file")
       .help("Input file to read")
       .required(false)
       .index(1))
